Forum Discussion
PSath2
New Contributor
6 years agoDevCloud: AOC Unable to compile kernels for device for any of the FPGA nodes: instantiates undefined entity "board" (reopened issue in new forum)
Ask a question about a DevCloud FPGA resource in the DevCloud forum, get feedback over a week and then randomly locked and redirected elsewhere. Guess the other forum's first-tier support staff was t...
PSath2
New Contributor
6 years agoMylee,
I am just returning from vacation, haven't gotten to try anything on the non-FPGA-queue nodes.
As the previous thread shows (before I was moved to this forum), I am trying a canonical OpenCL VectorAdd like follows:
__kernel void vectorAdd(__global float *A, __global float *B, __global float *C, int nelem) {
int tid = get_global_id(0);
if (tid < nelem) C[tid] = A[tid] + B[tid];
}The end goal is the 27 kernels in https://github.com/vetter/shoc/tree/master/src/opencl/level2/s3d
The examples you show are DPC++ which is a superset of SyCL, there are not OpenCL kernels in that repository. I am not sure if the DPC++ stack even uses AOC and all the old Altera stuff like the OpenCL stack does, so I am not sure how they're relevant. Our client has expressed that they want OpenCL, not SyCL, much less a vendor superset of it.